@@ -19,24 +19,21 @@
  * SECTION:soup-proxy-resolver-default
  * @short_description: System proxy configuration integration
  *
- * #SoupProxyResolverDefault is a #SoupProxyURIResolver implementation
- * that uses the default gio GProxyResolver to resolve proxies.
+ * #SoupProxyResolverDefault is a <type>SoupProxyURIResolver</type>
+ * implementation that uses the default gio #GProxyResolver to resolve
+ * proxies.
  *
- * Deprecated: In libsoup 2.44 and later, you can set the
+ * In libsoup 2.44 and later, you can set the session's
  * #SoupSession:proxy-resolver property to the resolver returned by
  * g_proxy_resolver_get_default() to get the same effect. Note that
  * for "plain" #SoupSessions (ie, not #SoupSessionAsync or
  * #SoupSessionSync), this is done for you automatically.
  *
  * Since: 2.34
+ *
+ * Deprecated: Use #SoupSession:proxy-resolver
  */
 
-static void soup_proxy_resolver_default_interface_init (SoupProxyURIResolverInterface *proxy_resolver_interface);
-
-G_DEFINE_TYPE_EXTENDED (SoupProxyResolverDefault, soup_proxy_resolver_default, G_TYPE_OBJECT, 0,
-			G_IMPLEMENT_INTERFACE (SOUP_TYPE_SESSION_FEATURE, NULL)
-			G_IMPLEMENT_INTERFACE (SOUP_TYPE_PROXY_URI_RESOLVER, soup_proxy_resolver_default_interface_init))
-
 enum {
 	PROP_0,
 	PROP_GPROXY_RESOLVER
@@ -45,7 +42,13 @@ enum {
 typedef struct {
 	GProxyResolver *gproxy_resolver;
 } SoupProxyResolverDefaultPrivate;
-#define SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), SOUP_TYPE_PROXY_RESOLVER_DEFAULT, SoupProxyResolverDefaultPrivate))
+
+static void soup_proxy_resolver_default_interface_init (SoupProxyURIResolverInterface *proxy_resolver_interface);
+
+G_DEFINE_TYPE_EXTENDED (SoupProxyResolverDefault, soup_proxy_resolver_default, G_TYPE_OBJECT, 0,
+                        G_ADD_PRIVATE (SoupProxyResolverDefault)
+			G_IMPLEMENT_INTERFACE (SOUP_TYPE_SESSION_FEATURE, NULL)
+			G_IMPLEMENT_INTERFACE (SOUP_TYPE_PROXY_URI_RESOLVER, soup_proxy_resolver_default_interface_init))
 
 static void
 soup_proxy_resolver_default_init (SoupProxyResolverDefault *resolver)
@@ -56,7 +59,8 @@ static void
 soup_proxy_resolver_default_set_property (GObject *object, guint prop_id,
 					  const GValue *value, GParamSpec *pspec)
 {
-	SoupProxyResolverDefaultPrivate *priv = SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE (object);
+	SoupProxyResolverDefault *resolver = SOUP_PROXY_RESOLVER_DEFAULT (object);
+	SoupProxyResolverDefaultPrivate *priv = soup_proxy_resolver_default_get_instance_private (resolver);
 
 	switch (prop_id) {
 	case PROP_GPROXY_RESOLVER:
@@ -73,7 +77,8 @@ soup_proxy_resolver_default_set_property (GObject *object, guint prop_id,
 static void
 soup_proxy_resolver_default_constructed (GObject *object)
 {
-	SoupProxyResolverDefaultPrivate *priv = SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE (object);
+	SoupProxyResolverDefault *resolver = SOUP_PROXY_RESOLVER_DEFAULT (object);
+	SoupProxyResolverDefaultPrivate *priv = soup_proxy_resolver_default_get_instance_private (resolver);
 
 	if (!priv->gproxy_resolver) {
 		priv->gproxy_resolver = g_proxy_resolver_get_default ();
@@ -86,7 +91,8 @@ soup_proxy_resolver_default_constructed (GObject *object)
 static void
 soup_proxy_resolver_default_finalize (GObject *object)
 {
-	SoupProxyResolverDefaultPrivate *priv = SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE (object);
+	SoupProxyResolverDefault *resolver = SOUP_PROXY_RESOLVER_DEFAULT (object);
+	SoupProxyResolverDefaultPrivate *priv = soup_proxy_resolver_default_get_instance_private (resolver);
 
 	g_clear_object (&priv->gproxy_resolver);
 
@@ -98,8 +104,6 @@ soup_proxy_resolver_default_class_init (SoupProxyResolverDefaultClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (klass, sizeof (SoupProxyResolverDefaultPrivate));
-
 	object_class->set_property = soup_proxy_resolver_default_set_property;
 	object_class->constructed = soup_proxy_resolver_default_constructed;
 	object_class->finalize = soup_proxy_resolver_default_finalize;
@@ -175,7 +179,8 @@ get_proxy_uri_async (SoupProxyURIResolver  *resolver,
 		     SoupProxyURIResolverCallback callback,
 		     gpointer		    user_data)
 {
-	SoupProxyResolverDefaultPrivate *priv = SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE (resolver);
+	SoupProxyResolverDefault *resolver_default = SOUP_PROXY_RESOLVER_DEFAULT (resolver);
+	SoupProxyResolverDefaultPrivate *priv = soup_proxy_resolver_default_get_instance_private (resolver_default);
 	SoupAsyncData *async_data;
 	char *uri_string;
 
@@ -208,7 +213,8 @@ get_proxy_uri_sync (SoupProxyURIResolver  *resolver,
 		    GCancellable	  *cancellable,
 		    SoupURI		 **proxy_uri)
 {
-	SoupProxyResolverDefaultPrivate *priv = SOUP_PROXY_RESOLVER_DEFAULT_GET_PRIVATE (resolver);
+	SoupProxyResolverDefault *resolver_default = SOUP_PROXY_RESOLVER_DEFAULT (resolver);
+	SoupProxyResolverDefaultPrivate *priv = soup_proxy_resolver_default_get_instance_private (resolver_default);
 	GError *error = NULL;
 	char** proxy_uris = NULL;
 	char *uri_string;
